@@ -28,6 +28,7 @@ import qualified Test.Tasty.Providers as T
 import Test.Tasty.Options
 
 import Hedgehog
+import Hedgehog.Internal.Config (UseColor(DisableColor))
 import Hedgehog.Internal.Property
 import Hedgehog.Internal.Runner as H
 import Hedgehog.Internal.Report
@@ -103,10 +104,19 @@ instance IsOption HedgehogShrinkRetries where
   optionName = return "hedgehog-retries"
   optionHelp = return "Number of times to re-run a test during shrinking"
 
+propertyTestLimit :: PropertyConfig -> TestLimit
+propertyTestLimit =
+  let
+    getTestLimit (EarlyTermination _ tests) = tests
+    getTestLimit (NoEarlyTermination _ tests) = tests
+    getTestLimit (NoConfidenceTermination tests) = tests
+  in
+    getTestLimit . propertyTerminationCriteria
+
 reportToProgress :: PropertyConfig
                  -> Report Progress
                  -> T.Progress
-reportToProgress config (Report testsDone _ status) =
+reportToProgress config (Report testsDone _ _ status) =
   let
     TestLimit testLimit = propertyTestLimit config
     ShrinkLimit shrinkLimit = propertyShrinkLimit config
@@ -123,21 +133,23 @@ reportOutput :: Bool
              -> String
              -> Report Result
              -> IO String
-reportOutput showReplay name report@(Report _ _ status) = do
-  -- TODO add details for tests run / discarded / shrunk
-  s <- renderResult Nothing (Just (PropertyName name)) report
-  pure $ case status of
-    Failed fr -> do
+reportOutput showReplay name report = do
+  s <- renderResult DisableColor (Just (PropertyName name)) report
+  pure $ case reportStatus report of
+    Failed fr ->
       let
         size = failureSize fr
         seed = failureSeed fr
         replayStr =
           if showReplay
-          then "\nUse '--hedgehog-replay \"" ++ show size ++ " " ++ show seed ++ "\"' to reproduce."
+          then
+            "\nUse '--hedgehog-replay \"" ++
+            show size ++ " " ++ show seed ++
+            "\"' to reproduce."
           else ""
-      s ++ replayStr
-    GaveUp -> "Gave up"
-    OK -> "OK"
+      in
+        s ++ replayStr ++ "\n"
+    _ -> s
 
 instance T.IsTest HP where
   testOptions =
@@ -159,10 +171,10 @@ instance T.IsTest HP where
       HedgehogShrinkRetries mRetries = lookupOption opts
       config =
         PropertyConfig
-          (fromMaybe (propertyTestLimit pConfig) mTests)
           (fromMaybe (propertyDiscardLimit pConfig) mDiscards)
           (fromMaybe (propertyShrinkLimit pConfig) mShrinks)
           (fromMaybe (propertyShrinkRetries pConfig) mRetries)
+          (NoConfidenceTermination $ fromMaybe (propertyTestLimit pConfig) mTests)
 
     randSeed <- Seed.random
     let
